==> openorienteering-mapper_0.6.8.orig.tar.gz: mapper-0.6.8/translations/OpenOrienteering_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>AutosaveDialog</name>
    <message numerus="yes">
        <location filename="../src/gui/autosave_dialog.cpp" line="45"/>
        <location filename="../src/gui/autosave_dialog.cpp" line="51"/>
        <source>%n bytes</source>
        <translation>
            <numerusform>%n byte</numerusform>
            <numerusform>%n bytes</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message numerus="yes">
        <location filename="../src/file_import_export.cpp" line="93"/>
        <source>Dropped %n irregular object(s).</source>
        <translation>
            <numerusform>Dropped one irregular object.</numerusform>
            <numerusform>Dropped %n irregular objects.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>MapEditorController</name>
    <message numerus="yes">
        <location filename="future_translations.cpp" line="37"/>
        <source>Cut %n object(s)</source>
        <extracomment>Past tense. Displayed when an Edit &gt; Cut operator is completed.</extracomment>
        <translation>
            <numerusform>Cut one object</numerusform>
            <numerusform>Cut %n objects</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="future_translations.cpp" line="40"/>
        <source>Copied %n object(s)</source>
        <extracomment>To replace existing translation which doesn't use plural correctly</extracomment>
        <translation>
            <numerusform>Copied one object</numerusform>
            <numerusform>Copied %n objects</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="future_translations.cpp" line="43"/>
        <source>Pasted %n object(s)</source>
        <extracomment>To replace existing translation which doesn't use plural correctly</extracomment>
        <translation>
            <numerusform>Pasted one object</numerusform>
            <numerusform>Pasted %n objects</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="future_translations.cpp" line="67"/>
        <source>Duplicated %n object(s)</source>
        <extracomment>To replace existing translation which doesn't use plural correctly</extracomment>
        <translation>
            <numerusform>Duplicated one object</numerusform>
            <numerusform>Duplicated %n objects</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>OCAD8FileImport</name>
    <message numerus="yes">
        <location filename="../src/file_format_ocad8.cpp" line="145"/>
        <source>%n color separation(s) were skipped, reason: Import disabled.</source>
        <translation>
            <numerusform>One color separation was skipped, reason: Import disabled.</numerusform>
            <numerusform>%n color separations were skipped, reason: Import disabled.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TagSelectWidget</name>
    <message numerus="yes">
        <location filename="../src/gui/widgets/tag_select_widget.cpp" line="346"/>
        <source>%n object(s) selected</source>
        <translation>
            <numerusform>One object selected</numerusform>
            <numerusform>%n objects selected</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TemplateTrack</name>
    <message numerus="yes">
        <location filename="../src/template_track.cpp" line="479"/>
        <source>%n path object(s) could not be imported (reason: missing coordinates).</source>
        <translation>
            <numerusform>One path object could not be imported (reason: missing coordinates).</numerusform>
            <numerusform>%n path objects could not be imported (reason: missing coordinates).</numerusform>
        </translation>
    </message>
</context>
</TS>

==> openorienteering-mapper_0.7.0.orig.tar.gz: mapper-0.7.0/translations/OpenOrienteering_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>AutosaveDialog</name>
    <message numerus="yes">
        <location filename="../src/gui/autosave_dialog.cpp" line="45"/>
        <location filename="../src/gui/autosave_dialog.cpp" line="51"/>
        <source>%n bytes</source>
        <translation>
            <numerusform>%n byte</numerusform>
            <numerusform>%n bytes</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message numerus="yes">
        <location filename="../src/fileformats/file_import_export.cpp" line="93"/>
        <source>Dropped %n irregular object(s).</source>
        <translation>
            <numerusform>Dropped one irregular object.</numerusform>
            <numerusform>Dropped %n irregular objects.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>MapEditorController</name>
    <message numerus="yes">
        <location filename="future_translations.cpp" line="37"/>
        <source>Cut %n object(s)</source>
        <extracomment>Past tense. Displayed when an Edit &gt; Cut operator is completed.</extracomment>
        <translation>
            <numerusform>Cut one object</numerusform>
            <numerusform>Cut %n objects</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="future_translations.cpp" line="40"/>
        <source>Copied %n object(s)</source>
        <extracomment>To replace existing translation which doesn't use plural correctly</extracomment>
        <translation>
            <numerusform>Copied one object</numerusform>
            <numerusform>Copied %n objects</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="future_translations.cpp" line="43"/>
        <source>Pasted %n object(s)</source>
        <extracomment>To replace existing translation which doesn't use plural correctly</extracomment>
        <translation>
            <numerusform>Pasted one object</numerusform>
            <numerusform>Pasted %n objects</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="future_translations.cpp" line="67"/>
        <source>Duplicated %n object(s)</source>
        <extracomment>To replace existing translation which doesn't use plural correctly</extracomment>
        <translation>
            <numerusform>Duplicated one object</numerusform>
            <numerusform>Duplicated %n objects</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>OCAD8FileImport</name>
    <message numerus="yes">
        <location filename="../src/fileformats/ocad8_file_format.cpp" line="146"/>
        <source>%n color separation(s) were skipped, reason: Import disabled.</source>
        <translation>
            <numerusform>One color separation was skipped, reason: Import disabled.</numerusform>
            <numerusform>%n color separations were skipped, reason: Import disabled.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>OgrFileImport</name>
    <message numerus="yes">
        <location filename="../src/gdal/ogr_file_format.cpp" line="442"/>
        <location filename="../src/gdal/ogr_file_format.cpp" line="447"/>
        <location filename="../src/gdal/ogr_file_format.cpp" line="452"/>
        <location filename="../src/gdal/ogr_file_format.cpp" line="457"/>
        <location filename="../src/gdal/ogr_file_format.cpp" line="462"/>
        <source>Unable to load %n objects, reason: %1</source>
        <translation><numerusform>Unable to load one object, reason: %1</numerusform>
        <numerusform>Unable to load %n objects, reason: %1</numerusform>
        </translation></message>
</context>
<context>
    <name>TagSelectWidget</name>
    <message numerus="yes">
        <location filename="../src/gui/widgets/tag_select_widget.cpp" line="346"/>
        <source>%n object(s) selected</source>
        <translation>
            <numerusform>One object selected</numerusform>
            <numerusform>%n objects selected</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TemplateTrack</name>
    <message numerus="yes">
        <location filename="../src/templates/template_track.cpp" line="475"/>
        <source>%n path object(s) could not be imported (reason: missing coordinates).</source>
        <translation>
            <numerusform>One path object could not be imported (reason: missing coordinates).</numerusform>
            <numerusform>%n path objects could not be imported (reason: missing coordinates).</numerusform>
        </translation>
    </message>
</context>
</TS>
